summaryrefslogtreecommitdiffstats
path: root/kolourpaint
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:19:40 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:19:40 -0600
commit74f47aebb77b4744bf18960b81c3744106cf56e0 (patch)
tree98f808be7ee64f341ba893cfc4fc6a2db7ed5092 /kolourpaint
parentc705f8f0619865875d6247d9470dced55241bc79 (diff)
downloadtdegraphics-74f47aebb77b4744bf18960b81c3744106cf56e0.tar.gz
tdegraphics-74f47aebb77b4744bf18960b81c3744106cf56e0.zip
Rename KApplication to TDEApplication to avoid conflicts with KDE4
Diffstat (limited to 'kolourpaint')
-rw-r--r--kolourpaint/kolourpaint.cpp2
-rw-r--r--kolourpaint/kpmainwindow_file.cpp2
-rw-r--r--kolourpaint/kpmainwindow_help.cpp2
-rw-r--r--kolourpaint/kptool.cpp16
4 files changed, 11 insertions, 11 deletions
diff --git a/kolourpaint/kolourpaint.cpp b/kolourpaint/kolourpaint.cpp
index 37a2032f..763fe668 100644
--- a/kolourpaint/kolourpaint.cpp
+++ b/kolourpaint/kolourpaint.cpp
@@ -176,7 +176,7 @@ int main (int argc, char *argv [])
TDECmdLineArgs::init (argc, argv, &aboutData);
TDECmdLineArgs::addCmdLineOptions (cmdLineOptions);
- KApplication app;
+ TDEApplication app;
// mainly for changing wallpaper :)
diff --git a/kolourpaint/kpmainwindow_file.cpp b/kolourpaint/kpmainwindow_file.cpp
index 4178bd0a..d7e77f1c 100644
--- a/kolourpaint/kpmainwindow_file.cpp
+++ b/kolourpaint/kpmainwindow_file.cpp
@@ -1352,7 +1352,7 @@ void kpMainWindow::setAsWallpaper (bool centered)
// I'm going to all this trouble because the user might not have tdebase
// installed so tdebase/kdesktop/KBackgroundIface.h might not be around
// to be compiled in (where user == developer :))
- if (!KApplication::dcopClient ()->send ("kdesktop", "KBackgroundIface",
+ if (!TDEApplication::dcopClient ()->send ("kdesktop", "KBackgroundIface",
"setWallpaper(TQString,int)", data))
{
KMessageBox::sorry (this, i18n ("Could not change wallpaper."));
diff --git a/kolourpaint/kpmainwindow_help.cpp b/kolourpaint/kpmainwindow_help.cpp
index c4609ac4..830ed6e8 100644
--- a/kolourpaint/kpmainwindow_help.cpp
+++ b/kolourpaint/kpmainwindow_help.cpp
@@ -110,7 +110,7 @@ void kpMainWindow::slotHelpTakingScreenshots ()
// TODO: Totally bogus logic if twin not running under same user as KolourPaint.
// SYNC: KWin contains PrintScreen key logic
- QCStringList dcopApps = KApplication::dcopClient ()->registeredApplications ();
+ QCStringList dcopApps = TDEApplication::dcopClient ()->registeredApplications ();
#if DEBUG_KP_MAIN_WINDOW
kdDebug () << "\tdcopApps=" << dcopApps << endl;
#endif
diff --git a/kolourpaint/kptool.cpp b/kolourpaint/kptool.cpp
index dd2eea9c..1aa58bf7 100644
--- a/kolourpaint/kptool.cpp
+++ b/kolourpaint/kptool.cpp
@@ -499,12 +499,12 @@ void kpTool::beginInternal ()
m_beganDraw = false;
- uint keyState = KApplication::keyboardModifiers ();
+ uint keyState = TDEApplication::keyboardModifiers ();
- m_shiftPressed = (keyState & KApplication::ShiftModifier);
- m_controlPressed = (keyState & KApplication::ControlModifier);
+ m_shiftPressed = (keyState & TDEApplication::ShiftModifier);
+ m_controlPressed = (keyState & TDEApplication::ControlModifier);
- // TODO: Can't do much about ALT - unless it's always KApplication::Modifier1?
+ // TODO: Can't do much about ALT - unless it's always TDEApplication::Modifier1?
// Ditto for everywhere else where I set SHIFT & CTRL but not alt.
m_altPressed = false;
}
@@ -1372,12 +1372,12 @@ void kpTool::keyUpdateModifierState (TQKeyEvent *e)
#if DEBUG_KP_TOOL && 0
kdDebug () << "\t\tmodifiers not changed - figure out the truth" << endl;
#endif
- uint keyState = KApplication::keyboardModifiers ();
+ uint keyState = TDEApplication::keyboardModifiers ();
- setShiftPressed (keyState & KApplication::ShiftModifier);
- setControlPressed (keyState & KApplication::ControlModifier);
+ setShiftPressed (keyState & TDEApplication::ShiftModifier);
+ setControlPressed (keyState & TDEApplication::ControlModifier);
- // TODO: Can't do much about ALT - unless it's always KApplication::Modifier1?
+ // TODO: Can't do much about ALT - unless it's always TDEApplication::Modifier1?
// Ditto for everywhere else where I set SHIFT & CTRL but not alt.
setAltPressed (e->stateAfter () & TQt::AltButton);
}